# PAMIQ Core Sample Projects

This directory contains sample implementations demonstrating different use cases of pamiq-core:

- [**minimum.py**](./minimum.py) - Minimal setup example

- [**vae-torch**](./vae-torch/) - VAE training with PyTorch integration

- [**pamiq-vrchat**](https://github.com/MLShukai/pamiq-vrchat?tab=readme-ov-file#-running-the-sample-project) - The autonomous agent on VRChat (see `src/sample/`)

    [![PAMIQ VRChat Video](http://img.youtube.com/vi/hYjet0v17rY/0.jpg)](https://youtu.be/hYjet0v17rY)
